==> postgrid_python-2.0.0.tar.gz: postgrid_python-2.0.0/CHANGELOG.md <==
# Changelog

## 2.0.0 (2025-11-13)

Full Changelog: [v0.0.1-alpha.0...v2.0.0](https://github.com/postgrid/postgrid-python/compare/v0.0.1-alpha.0...v2.0.0)

### Bug Fixes

* **api:** Pacify pyright ([0dea36d](https://github.com/postgrid/postgrid-python/commit/0dea36d9fcab59fec8412c753bc66b4dbc5b99e1))
* **api:** Prepare request fix ([9f737cc](https://github.com/postgrid/postgrid-python/commit/9f737cc73d70892712759f52624ade9f9bd8ba7e))
* **api:** remove unsupported collaterals ([fdbeb1a](https://github.com/postgrid/postgrid-python/commit/fdbeb1a3cf24dfbdaff4bf08966b6b04853e2840))
* compat with Python 3.14 ([53457ab](https://github.com/postgrid/postgrid-python/commit/53457abee1fea7154fd0918aa194f106ff4a9a51))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([899cab3](https://github.com/postgrid/postgrid-python/commit/899cab3df49e481eee336a3e585df7bb58334b0b))
* **readme:** rename PostGrid ([c23572a](https://github.com/postgrid/postgrid-python/commit/c23572aeb87f04560983d0bdc664fecd393bab2a))


### Chores

* **internal:** codegen related update ([3b415ec](https://github.com/postgrid/postgrid-python/commit/3b415ece8193658f82764f82f6e6c55575b3d005))
* **package:** drop Python 3.8 support ([e2e6808](https://github.com/postgrid/postgrid-python/commit/e2e6808b739591baf7258c1ea49fca1d83b09dfc))
* sync repo ([3f005c5](https://github.com/postgrid/postgrid-python/commit/3f005c5c29d1583544b1e55269fe71b07f165d13))
* update SDK settings ([8831e90](https://github.com/postgrid/postgrid-python/commit/8831e903672a9e505744acb42af75da40c816f61))
* update SDK settings ([277f25a](https://github.com/postgrid/postgrid-python/commit/277f25a1fa957073e355fba73bfa783b85adb2ad))

==> postgrid_python-2.0.1.tar.gz: postgrid_python-2.0.1/CHANGELOG.md <==
# Changelog

## 2.0.1 (2025-11-22)

Full Changelog: [v2.0.0...v2.0.1](https://github.com/postgrid/postgrid-python/compare/v2.0.0...v2.0.1)

### Chores

* add Python 3.14 classifier and testing ([7e2917a](https://github.com/postgrid/postgrid-python/commit/7e2917a5dec82c83534abca2719438830bed406e))

## 2.0.0 (2025-11-13)

Full Changelog: [v0.0.1-alpha.0...v2.0.0](https://github.com/postgrid/postgrid-python/compare/v0.0.1-alpha.0...v2.0.0)

### Bug Fixes

* **api:** Pacify pyright ([0dea36d](https://github.com/postgrid/postgrid-python/commit/0dea36d9fcab59fec8412c753bc66b4dbc5b99e1))
* **api:** Prepare request fix ([9f737cc](https://github.com/postgrid/postgrid-python/commit/9f737cc73d70892712759f52624ade9f9bd8ba7e))
* **api:** remove unsupported collaterals ([fdbeb1a](https://github.com/postgrid/postgrid-python/commit/fdbeb1a3cf24dfbdaff4bf08966b6b04853e2840))
* compat with Python 3.14 ([53457ab](https://github.com/postgrid/postgrid-python/commit/53457abee1fea7154fd0918aa194f106ff4a9a51))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([899cab3](https://github.com/postgrid/postgrid-python/commit/899cab3df49e481eee336a3e585df7bb58334b0b))
* **readme:** rename PostGrid ([c23572a](https://github.com/postgrid/postgrid-python/commit/c23572aeb87f04560983d0bdc664fecd393bab2a))


### Chores

* **internal:** codegen related update ([3b415ec](https://github.com/postgrid/postgrid-python/commit/3b415ece8193658f82764f82f6e6c55575b3d005))
* **package:** drop Python 3.8 support ([e2e6808](https://github.com/postgrid/postgrid-python/commit/e2e6808b739591baf7258c1ea49fca1d83b09dfc))
* sync repo ([3f005c5](https://github.com/postgrid/postgrid-python/commit/3f005c5c29d1583544b1e55269fe71b07f165d13))
* update SDK settings ([8831e90](https://github.com/postgrid/postgrid-python/commit/8831e903672a9e505744acb42af75da40c816f61))
* update SDK settings ([277f25a](https://github.com/postgrid/postgrid-python/commit/277f25a1fa957073e355fba73bfa783b85adb2ad))
